@@ -21,21 +21,31 @@ get_ra_path <- function(node_id, tree, default_op = TRUE) {
       rb <- tree[tree$nodeID == .y, ]
       lc <- rb["leftChild"] == .x
       lr <- rb["rightChild"] == .x
-      if (is.na(lc)) lc <- FALSE
-      if (is.na(lr)) lr <- FALSE
-      if (default_op) {
-        if (rb["leftChild"] == .x) op <- "less"
-        if (rb["rightChild"] == .x) op <- "more-equal"
+      if (is.na(rb["splitval"][[1]])) {
+        if (lc) op <- "in"
+        if (lr) op <- "not-in"
+        vals <- strsplit(as.character(rb["splitclass"][[1]]), ", ")[[1]]
+        list(
+          type = "set",
+          col = as.character(rb["splitvarName"][[1]]),
+          vals = map(vals, ~.x),
+          op = op
+        )
       } else {
-        if (rb["leftChild"] == .x) op <- "less-equal"
-        if (rb["rightChild"] == .x) op <- "more"
+        if (default_op) {
+          if (lc) op <- "less"
+          if (lr) op <- "more-equal"
+        } else {
+          if (lc) op <- "less-equal"
+          if (lr) op <- "more"
+        }
+        list(
+          type = "conditional",
+          col = as.character(rb["splitvarName"][[1]]),
+          val = rb["splitval"][[1]],
+          op = op
+        )
       }
-      list(
-        type = "conditional",
-        col = as.character(rb["splitvarName"][[1]]),
-        val = rb["splitval"][[1]],
-        op = op
-      )
     }
   )
 }
@@ -48,31 +58,30 @@ get_ra_tree <- function(tree_no, model) {
     ~ {
       prediction <- tree$prediction[tree$nodeID == .x]
       if (!is.null(prediction)) {
-        if (is.factor(prediction)) prediction <- as.character(prediction)  
+        if (is.factor(prediction)) prediction <- as.character(prediction)
         list(
           prediction = prediction,
           path = get_ra_path(.x, tree, TRUE)
-        )        
+        )
       } else {
-        preds <- map_lgl(colnames(tree), ~"pred." == substr(.x, 1, 5))
+        preds <- map_lgl(colnames(tree), ~ "pred." == substr(.x, 1, 5))
         preds_table <- tree[tree$nodeID == .x, preds]
-        predictors <- map_chr(colnames(preds_table), ~substr(.x, 6, nchar(.x)))
+        predictors <- map_chr(colnames(preds_table), ~ substr(.x, 6, nchar(.x)))
         colnames(preds_table) <- predictors
         predictions <- map(preds_table, ~.x)
-        max_pred <- map_lgl(predictions, ~.x == max(map_dbl(predictions, ~.x)))
+        max_pred <- map_lgl(predictions, ~ .x == max(map_dbl(predictions, ~.x)))
         prediction <- names(predictions)[max_pred]
         prediction <- prediction[[1]]
         prob <- predictions[max_pred]
         prob <- prob[[1]]
-        predictions <- imap(predictions, ~list(pred = .y, prob = .x))
+        predictions <- imap(predictions, ~ list(pred = .y, prob = .x))
         list(
           prediction = prediction,
           prob = prob,
           probs = predictions,
           path = get_ra_path(.x, tree, TRUE)
-        )       
+        )
       }
-
     }
   )
 }
