@@ -17,7 +17,7 @@ tidypredict_to_column <- function(df, model, add_interval = FALSE,
                                   interval = 0.95, vars = c("fit", "upper", "lower")) {
   fit_model <- tidypredict_fit(model)
 
-  if (class(fit_model) == "list") stop("tidypredict_to_column does not support tree based models")
+  if (inherits(fit_model, "list")) cli::cli_abort("tidypredict_to_column does not support tree based models")
 
   fit <- vars[1]
   upper <- vars[2]
