@@ -1,10 +1,10 @@
-context("test-list")
-
 fitted_rf <- function(...) tidypredict_fit(parse_model(...))
 
+skip_if_not_installed("randomForest")
+
 test_that("Supports parsed models in list objects", {
-  expect_is(
-    fitted_rf(lm(mpg ~ wt, data = mtcars)),
+  expect_equal(
+    class(fitted_rf(lm(mpg ~ wt, data = mtcars)))[1],
     "call"
   )
   expect_equal(
